import React, { useState, useEffect } from 'react';
import ToggleIcon from '@material-ui/icons/PlayCircleFilled';
import DeleteIcon from '@material-ui/icons/Delete';
import CancelIcon from '@material-ui/icons/Cancel';
import EditIcon from '@material-ui/icons/Edit';
import FileCopyIcon from '@material-ui/icons/FileCopy';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var DataLabel = function DataLabel(_ref) {
  var type = _ref.type;
  return React.createElement("span", {
    style: {
      padding: '0px 6px',
      color: 'gray',
      border: '1px solid gray',
      borderRadius: 5,
      fontSize: 11,
      margin: '0 3px'
    }
  }, type);
};

var JsonNumber = function JsonNumber(_ref) {
  var value = _ref.value,
      dataKey = _ref.dataKey,
      dataType = _ref.dataType,
      onEdit = _ref.onEdit,
      onDelete = _ref.onDelete;

  var _useState = useState(),
      currentValue = _useState[0],
      setCurrentValue = _useState[1];

  var _useState2 = useState(false),
      showInput = _useState2[0],
      setShowInput = _useState2[1];

  useEffect(function () {
    setCurrentValue(value);
  }, [value]);

  var showEditInput = function showEditInput() {
    setShowInput(true);
  };

  var editValue = function editValue() {
    onEdit(currentValue, dataKey);
    setShowInput(false);
  };

  var deleteValue = function deleteValue() {
    onDelete(dataKey);
    setShowInput(false);
  };

  var cancelEdit = function cancelEdit() {
    setShowInput(false);
  };

  return React.createElement("div", {
    className: 'p5'
  }, React.createElement("span", null, React.createElement("span", null, "\""), React.createElement("span", null, dataKey), React.createElement("span", null, "\""), " : ", React.createElement(DataLabel, {
    type: dataType
  }), showInput ? React.createElement("span", null, React.createElement("input", {
    className: 'p5 NumProperty',
    type: 'number',
    defaultValue: currentValue,
    onChange: function onChange(e) {
      return setCurrentValue(e.target.value);
    }
  }), React.createElement(EditIcon, {
    style: {
      cursor: 'pointer'
    },
    className: 'editIcon',
    onClick: editValue
  }), React.createElement(DeleteIcon, {
    style: {
      cursor: 'pointer'
    },
    className: 'deleteIcon',
    onClick: deleteValue
  }), React.createElement(CancelIcon, {
    style: {
      cursor: 'pointer'
    },
    className: 'cancelIcon',
    onClick: cancelEdit
  })) : React.createElement("span", {
    style: {
      color: 'blue'
    },
    onClick: showEditInput
  }, currentValue)));
};

var JsonString = function JsonString(_ref) {
  var value = _ref.value,
      dataKey = _ref.dataKey,
      dataType = _ref.dataType,
      onEdit = _ref.onEdit,
      onDelete = _ref.onDelete;

  var _useState = useState(),
      currentValue = _useState[0],
      setCurrentValue = _useState[1];

  var _useState2 = useState(false),
      showInput = _useState2[0],
      setShowInput = _useState2[1];

  useEffect(function () {
    setCurrentValue(value);
  }, [value]);

  var showEditInput = function showEditInput() {
    setShowInput(true);
  };

  var editValue = function editValue() {
    onEdit(currentValue, dataKey);
    setShowInput(false);
  };

  var deleteValue = function deleteValue() {
    onDelete(dataKey);
    setShowInput(false);
  };

  var cancelEdit = function cancelEdit() {
    setShowInput(false);
  };

  return React.createElement("div", {
    style: {
      padding: 5
    }
  }, React.createElement("span", null, React.createElement("span", null, "\""), React.createElement("span", null, dataKey), React.createElement("span", null, "\""), " : ", React.createElement(DataLabel, {
    type: dataType
  }), React.createElement("span", null, "\""), React.createElement("span", {
    style: {
      color: '#FF6767'
    }
  }, showInput ? React.createElement("span", null, React.createElement("textarea", {
    className: 'textInput',
    style: {
      padding: 5
    },
    defaultValue: currentValue,
    onChange: function onChange(e) {
      return setCurrentValue(e.target.value);
    }
  }), React.createElement("span", null, React.createElement(EditIcon, {
    style: {
      cursor: 'pointer'
    },
    className: 'editIcon',
    onClick: editValue
  })), React.createElement(DeleteIcon, {
    style: {
      cursor: 'pointer'
    },
    className: 'deleteIcon',
    onClick: deleteValue
  }), React.createElement(CancelIcon, {
    style: {
      cursor: 'pointer'
    },
    className: 'cancelIcon',
    onClick: cancelEdit
  })) : React.createElement("span", {
    className: 'JsonValue',
    onClick: showEditInput
  }, currentValue)), React.createElement("span", null, "\"")));
};

var JsonBool = function JsonBool(_ref) {
  var value = _ref.value,
      dataKey = _ref.dataKey,
      dataType = _ref.dataType;
  return React.createElement("div", {
    style: {
      padding: 5
    }
  }, React.createElement("span", null, React.createElement("span", null, "\""), React.createElement("span", null, dataKey), React.createElement("span", null, "\""), " : ", React.createElement(DataLabel, {
    type: dataType
  }), React.createElement("span", {
    style: {
      color: 'green'
    }
  }, value)));
};

function getTypes(value) {
  if (Array.isArray(value)) return 'array';
  return typeof value;
}

var JsonObject = function JsonObject(_ref) {
  var value = _ref.value,
      dataKey = _ref.dataKey,
      dataType = _ref.dataType,
      onDelete = _ref.onDelete;

  var _useState = useState(true),
      col = _useState[0],
      setCol = _useState[1];

  var _useState2 = useState([]),
      keys = _useState2[0],
      setKeys = _useState2[1];

  var _useState3 = useState({}),
      currentValue = _useState3[0],
      setCurrentValue = _useState3[1];

  useEffect(function () {
    setCurrentValue(value);
    setKeys(Object.keys(value ? value : ""));
  }, [value]);

  var EditOneProperty = function EditOneProperty(newValue, key) {
    var newObj = _extends({}, currentValue);

    newObj[key] = newValue;
    setCurrentValue(newObj);
  };

  var DeleteOneProperty = function DeleteOneProperty(key) {
    var newObj = _extends({}, currentValue); // newObj = _.omit(currentValue, key);


    currentValue ? delete newObj[key] : "";
    newObj ? setCurrentValue(newObj) : "";
    newObj ? setKeys(Object.keys(newObj)) : "";
  };

  var renderObject = function renderObject() {
    return keys.map(function (k, i) {
      return React.createElement(Index, {
        key: i,
        dataType: currentValue ? getTypes(currentValue[k]) : "",
        dataValue: currentValue ? currentValue[k] : "",
        dataKey: k,
        onEdit: EditOneProperty,
        onDelete: DeleteOneProperty
      });
    });
  };

  var renderObjContent = function renderObjContent() {
    if (col) return React.createElement("div", {
      className: 'p5 ml6'
    }, React.createElement("div", {
      onClick: toggleObj
    }, React.createElement(ToggleIcon, {
      onClick: toggleObj,
      className: 'collapseIcon',
      style: {
        cursor: 'pointer'
      }
    }), React.createElement("span", null, "\"", dataKey, "\""), React.createElement("span", null, ":"), React.createElement("span", {
      className: 'boldStyle pl5'
    }, '{'), React.createElement("span", null, React.createElement(DeleteIcon, {
      style: {
        cursor: 'pointer'
      },
      className: 'deleteIcon',
      onClick: function onClick() {
        onDelete(dataKey);
      }
    }), React.createElement(CancelIcon, {
      className: 'cancelIcon',
      style: {
        cursor: 'pointer'
      }
    })), React.createElement(DataLabel, {
      type: dataType ? dataType : ""
    })), React.createElement("div", {
      className: 'pl12'
    }, renderObject(), React.createElement("div", null, React.createElement("span", {
      className: 'boldStyle'
    }, '}'))));
    return React.createElement("div", {
      className: 'p5 ml6'
    }, React.createElement("div", null, React.createElement(ToggleIcon, {
      onClick: toggleObj,
      className: 'collapseIcon'
    }), "\"", dataKey, "\":", React.createElement("span", {
      className: 'boldStyle'
    }, '{', React.createElement(DataLabel, {
      type: dataType ? dataType : ""
    })), React.createElement("span", {
      className: 'colorGray'
    }, keys.length, " items"), React.createElement("span", {
      className: 'boldStyle'
    }, '}')));
  };

  var toggleObj = function toggleObj() {
    // setCurrentValue(currentValue);
    setCol(!col);
  };

  return renderObjContent();
};

var JsonArray = function JsonArray(_ref) {
  var value = _ref.value,
      dataKey = _ref.dataKey,
      dataType = _ref.dataType;

  var _useState = useState(false),
      col = _useState[0],
      setCol = _useState[1];

  var _useState2 = useState([]),
      currentValue = _useState2[0],
      setCurrentValue = _useState2[1];

  useEffect(function () {
    setCurrentValue(value);
  }, [value]);

  var editOneFromArray = function editOneFromArray(newValue, key) {
    var temp_state = [].concat(currentValue);
    if (typeof key === "number") temp_state[key] = newValue;
    setCurrentValue(temp_state);
  };

  var deleteOneFromArray = function deleteOneFromArray(key) {
    var tempArray = [].concat(currentValue);
    if (typeof key === "number") tempArray.splice(key, 1);
    setCurrentValue(tempArray);
  };

  var renderArrayContent = function renderArrayContent() {
    return currentValue.map(function (v, i) {
      var type = getTypes(v);
      return React.createElement(Index, {
        key: i,
        dataValue: v,
        dataType: type,
        dataKey: i,
        onEdit: editOneFromArray,
        onDelete: deleteOneFromArray
      });
    });
  };

  var renderContent = function renderContent() {
    if (col) {
      return React.createElement("div", {
        className: 'p5 ml6'
      }, React.createElement("span", null, React.createElement(ToggleIcon, {
        style: {
          cursor: 'pointer'
        },
        onClick: toggleArray,
        className: 'collapseIcon'
      }), React.createElement("span", null, "\""), React.createElement("span", null, dataKey), React.createElement("span", null, "\""), " : ", React.createElement(DataLabel, {
        type: dataType
      }), React.createElement("span", {
        className: 'boldStyle'
      }, "["), React.createElement("span", {
        className: 'colorGray'
      }, currentValue.length, " items"), React.createElement("span", {
        className: 'boldStyle'
      }, "]")));
    }

    return React.createElement("div", {
      className: 'p5 ml6'
    }, React.createElement("span", null, React.createElement(ToggleIcon, {
      style: {
        cursor: 'pointer'
      },
      onClick: toggleArray,
      className: 'collapseIcon'
    }), React.createElement("span", null, "\""), React.createElement("span", null, dataKey), React.createElement("span", null, "\""), " : ", React.createElement(DataLabel, {
      type: dataType
    }), React.createElement("span", {
      className: 'boldStyle'
    }, "["), renderArrayContent(), React.createElement("span", {
      className: 'boldStyle'
    }, "]")));
  };

  var toggleArray = function toggleArray() {
    setCol(!col);
  };

  return renderContent();
};

var JsonFunction = function JsonFunction(_ref) {
  var dataKey = _ref.dataKey,
      dataType = _ref.dataType;
  return React.createElement("div", {
    className: 'p5'
  }, React.createElement("span", null, React.createElement("span", null, "\""), React.createElement("span", null, dataKey), React.createElement("span", null, "\""), " : ", React.createElement(DataLabel, {
    type: dataType
  }), React.createElement("span", {
    style: {
      color: 'blue'
    }
  }, "Function()")));
};

var Index = function Index(_ref) {
  var dataType = _ref.dataType,
      dataValue = _ref.dataValue,
      dataKey = _ref.dataKey,
      onEdit = _ref.onEdit,
      onDelete = _ref.onDelete;

  var renderValue = function renderValue() {
    switch (dataType) {
      case 'number':
        return React.createElement(JsonNumber, {
          value: dataValue,
          dataKey: dataKey,
          dataType: dataType,
          onEdit: onEdit,
          onDelete: onDelete
        });

      case 'string':
        return React.createElement(JsonString, {
          value: dataValue,
          dataKey: dataKey,
          dataType: dataType,
          onEdit: onEdit,
          onDelete: onDelete
        });

      case 'object':
        return React.createElement(JsonObject, {
          value: dataValue,
          dataKey: dataKey,
          dataType: dataType,
          onDelete: onDelete,
          onEdit: onEdit
        });

      case 'boolean':
        return React.createElement(JsonBool, {
          value: dataValue,
          dataKey: dataKey,
          dataType: dataType
        });

      case 'array':
        return React.createElement(JsonArray, {
          value: dataValue,
          dataKey: dataKey,
          dataType: dataType
        });

      case 'function':
        return React.createElement(JsonFunction, {
          value: dataValue,
          dataKey: dataKey,
          dataType: dataType
        });

      default:
        return null;
    }
  };

  return renderValue();
};

var DataView = function DataView(_ref) {
  var data = _ref.data,
      onDelete = _ref.onDelete,
      onEdit = _ref.onEdit;

  var _useState = useState(false),
      col = _useState[0],
      setCol = _useState[1];

  var _useState2 = useState([]),
      keys = _useState2[0],
      setKeys = _useState2[1];

  var _useState3 = useState({}),
      currentData = _useState3[0],
      setCurrentData = _useState3[1];

  useEffect(function () {
    var newkeys = Object.getOwnPropertyNames(data);
    setKeys(newkeys);
    setCurrentData(data);
  }, [data]);

  var copyDataToClipboard = function copyDataToClipboard() {
    navigator.clipboard.writeText(JSON.stringify(data));
  };

  var toggleJsonView = function toggleJsonView() {
    setCol(!col);
  };

  var renderData = function renderData() {
    if (col) return React.createElement("div", {
      className: 'p5'
    }, React.createElement("span", {
      className: 'colorGray'
    }, React.createElement("span", null, '{'), currentData ? Object.keys(currentData).length : "", " items", React.createElement("span", null, '}')));
    return keys.map(function (k) {
      return React.createElement("div", {
        key: k
      }, React.createElement(Index, {
        key: k,
        dataType: currentData ? getTypes(currentData[k]) : "",
        dataValue: currentData ? currentData[k] : "",
        dataKey: k,
        onEdit: onEdit,
        onDelete: onDelete
      }));
    });
  };

  return React.createElement("div", {
    className: 'JsonTree'
  }, React.createElement("div", null, React.createElement(ToggleIcon, {
    style: {
      cursor: 'pointer'
    },
    onClick: toggleJsonView,
    className: 'mainCollapseIcon'
  }), "\"root\" :", React.createElement("span", {
    className: 'boldStyle pl5'
  }, '{', React.createElement(FileCopyIcon, {
    style: {
      fontSize: 16,
      color: 'gray',
      cursor: 'pointer'
    },
    onClick: copyDataToClipboard
  })), renderData(), React.createElement("div", {
    className: 'boldStyle '
  }, '}')));
};

var JsJsonView = function JsJsonView(_ref) {
  var resource = _ref.resource;

  var _useState = useState({}),
      currentResource = _useState[0],
      setCurrentResource = _useState[1];

  useEffect(function () {
    setCurrentResource(resource);
  }, [resource]); // edit a property from the object

  var EditObj = function EditObj(newValue, key) {
    var newObj = _extends({}, currentResource);

    newObj[key] = newValue;
    setCurrentResource(newObj);
  }; // delete a property from the object


  var DeleteObj = function DeleteObj(key) {
    var currentValue = _extends({}, currentResource);

    delete currentValue[key]; // _.omit(currentResource, key)

    setCurrentResource(currentValue);
  };

  return React.createElement("div", {
    className: 'appContainer',
    "data-testid": 'Json-tree'
  }, React.createElement(DataView, {
    data: currentResource,
    onDelete: DeleteObj,
    onEdit: EditObj
  }));
};

export default JsJsonView;
//# sourceMappingURL=js-json-tree.esm.js.map
